@@ -110,6 +110,7 @@ static char const G_line[] =
   '.','Z',' ','0','1',';','3','1',0,
   '.','d','z',' ','0','1',';','3','1',0,
   '.','g','z',' ','0','1',';','3','1',0,
+  '.','l','z',' ','0','1',';','3','1',0,
   '.','x','z',' ','0','1',';','3','1',0,
   '.','b','z','2',' ','0','1',';','3','1',0,
   '.','b','z',' ','0','1',';','3','1',0,
@@ -168,6 +169,8 @@ static char const G_line[] =
   '.','x','c','f',' ','0','1',';','3','5',0,
   '.','x','w','d',' ','0','1',';','3','5',0,
   '.','y','u','v',' ','0','1',';','3','5',0,
+  '.','c','g','m',' ','0','1',';','3','5',0,
+  '.','e','m','f',' ','0','1',';','3','5',0,
   '#',' ','h','t','t','p',':','/','/','w','i','k','i','.','x','i','p','h','.','o','r','g','/','i','n','d','e','x','.','p','h','p','/','M','I','M','E','_','T','y','p','e','s','_','a','n','d','_','F','i','l','e','_','E','x','t','e','n','s','i','o','n','s',0,
   '.','a','x','v',' ','0','1',';','3','5',0,
   '.','a','n','x',' ','0','1',';','3','5',0,
